@@ -38,7 +38,7 @@ _defaults = {
     'profile_files'     : ('project.apache.conf', 'trac-defaults.ini', 'permissions.ini')
 }
 
-_version = '0.4.2dev'
+_version = '0.4.3'
 
 class CleverboxAdmin(cmd.Cmd):
     intro = ''
@@ -72,6 +72,15 @@ class CleverboxAdmin(cmd.Cmd):
         # Check if environment needs an upgrade
         #  - open VERSION
         try:
+            import trac
+            if trac.__version__ == '0.10.3':
+                print
+                print "A bug in trac-0.10.3 prevents the cleverbox from working correctly."
+                print "Please upgrade or downgrade your trac installation."
+                print
+                
+                sys.exit(1)
+            
             env_version = open(os.path.join(self.envname, 'VERSION')).read().strip()
             
             #  - compare with self._version
@@ -926,7 +935,6 @@ Include %(env_dir)s/projects-enabled/%(client_name)s-*
         db_cursor.execute('DELETE FROM permission')
         trac_db.commit()
         
-        print
         print "  Revoked Trac default permissions\n"
 
     def _project_fix_perms(self, infos):
