@@ -33,3 +33,14 @@ def do_upgrade_2(envname, env_version):
     f.close()
 
     print "Done upgrading"
+
+def do_upgrade_3(envname, env_version):
+    import os
+
+    print "Upgrading to cleverbox-0.4.3"
+
+    f = open(os.path.join(envname, 'VERSION'), 'w')
+    f.write('0.4.3')
+    f.close()
+
+    print "Done upgrading"
